@@ -3,14 +3,17 @@ use crate::colorizer::Colorizer;
 pub struct Bar;
 
 impl Bar {
-    pub fn new_disk(percent_disk: f64, percent_inodes: f64) -> String {
+    pub fn new_disk(percent_disk: f64, percent_inodes: f64, is_copy_friendly: bool) -> String {
         let bar_length = 20;
         let bar_unit = "■";
+        let bar_unit_empty = "□";
         let count_inode_units = Bar::compute_bar_units(percent_inodes, bar_length);
         let count_disk_units = Bar::compute_bar_units(percent_disk, bar_length);
         Colorizer::colorize_bar(
             bar_length,
             bar_unit,
+            bar_unit_empty,
+            is_copy_friendly,
             count_disk_units,
             count_inode_units,
             percent_disk,
